@@ -19,8 +19,8 @@ import gdb
 import os
 import os.path
 
-pythondir = '/builder/x86_generic/build/staging_dir/toolchain-i386_pentium4_gcc-7.3.0_musl/share/gcc-7.3.0/python'
-libdir = '/builder/x86_generic/build/staging_dir/toolchain-i386_pentium4_gcc-7.3.0_musl/i486-openwrt-linux-musl/lib'
+pythondir = '/home/uxgood/work/uxgood.github.com/openwrt/build-x86-18.06.4/staging_dir/toolchain-i386_pentium4_gcc-7.3.0_musl/share/gcc-7.3.0/python'
+libdir = '/home/uxgood/work/uxgood.github.com/openwrt/build-x86-18.06.4/staging_dir/toolchain-i386_pentium4_gcc-7.3.0_musl/i486-openwrt-linux-musl/lib'
 
 # This file might be loaded when there is no current objfile.  This
 # can happen if the user loads it manually.  In this case we don't
